==> haskell-src-meta-0.7.0.1-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.7.0.1
id: haskell-src-meta-0.7.0.1-EJjM1yqZ1Mq3N9qWDIgboN
key: haskell-src-meta-0.7.0.1-EJjM1yqZ1Mq3N9qWDIgboN
license: BSD3
copyright: (c) Matt Morrow
maintainer: Ben Millwood <haskell@benmachine.co.uk>
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Parse.Careful
    Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.TH.Instances.Lift Language.Haskell.Meta.Utils
abi: 67c043c1cf56bb083faef9d167a44d69
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-meta-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-meta-0.7.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/haskell-src-meta-0.7.0.1
hs-libraries: HShaskell-src-meta-0.7.0.1-EJjM1yqZ1Mq3N9qWDIgboN
depends:
    base-4.9.0.0 haskell-src-exts-1.18.2-7JYrbgADd3D34kjxtkSbG9
    pretty-1.1.3.3 syb-0.6-C65vWCsht6A8uLstpQIXyj
    template-haskell-2.11.0.0 th-orphans-0.13.3-KQRIg7deSjG6NWnqF3AtaQ
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.7.0.1-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.7.0.1
id: haskell-src-meta-0.7.0.1-7WsABa0GVm9ZVPlVApUIR
key: haskell-src-meta-0.7.0.1-7WsABa0GVm9ZVPlVApUIR
license: BSD3
copyright: (c) Matt Morrow
maintainer: Ben Millwood <haskell@benmachine.co.uk>
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Parse.Careful
    Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.TH.Instances.Lift Language.Haskell.Meta.Utils
abi: b94ef31de002127dc85ed028ae23cb48
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-meta-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-meta-0.7.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/haskell-src-meta-0.7.0.1
hs-libraries: HShaskell-src-meta-0.7.0.1-7WsABa0GVm9ZVPlVApUIR
depends:
    base-4.9.0.0 haskell-src-exts-1.18.2-HHC3x3A3NPPIRZVmSBLAjX
    pretty-1.1.3.3 syb-0.6-C65vWCsht6A8uLstpQIXyj
    template-haskell-2.11.0.0 th-orphans-0.13.3-cs9TXYbtCJFIfdSAphexL
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
